@@ -10,13 +10,18 @@ import glowworm.pysmart
 import glowworm.extend
 import os
 import sys
+import pkgutil
+
 
 # 依次扫描glowworm下所有除main的模块
-for m in os.listdir(__name__):  # glowworm包
-    # 将包下的所有模块，逐个导入，并调用其中的函数
-    if m.startswith('__') or m == 'main.py':
+for importer, modname, ispkg in pkgutil.iter_modules(path=['glowworm']):
+    if ispkg:
         continue
-    sp = __name__ + '.' + m.split('.')[0]
+    print(modname)
+    # 将包下的所有模块，逐个导入，并调用其中的函数
+    if modname.startswith('__') or modname == 'main':
+        continue
+    sp = __name__ + '.' + modname
     try:
         for name, class_ in getmembers(sys.modules[sp], isclass):
             if class_.__base__ != pysmart.Base:
@@ -25,7 +30,7 @@ for m in os.listdir(__name__):  # glowworm包
             _basic_dict = {smart_dict[f].__doc__: smart_dict[f] for f in smart_dict
                            if isfunction(smart_dict[f])}
     except KeyError as key_err:
-        print('warn: 模块{}中没有类或没有继承Base类'.format(m))
+        print('warn: 模块{}中没有类或没有继承Base类'.format(modname))
         continue
 
 # 不要移动main这行代码
